@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "pygn-mode" "0.6.3"
+(define-package "pygn-mode" "20241216.1959"
   "Major-mode for chess PGN files, powered by Python."
   '((emacs             "26.1")
     (tree-sitter       "0.15.2")
@@ -9,5 +9,5 @@
     (ivy               "0.10.0"))
   :url "https://github.com/dwcoates/pygn-mode"
   :commit "3f1ce4efd1c34b9fc347c848eb4426bfcc851118"
-  :revdesc "v0.6.3-0-g3f1ce4efd1c3"
+  :revdesc "3f1ce4efd1c3"
   :keywords '("data" "games" "chess"))
